# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/adapter_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2dbtlabs/proto/public/v1/fields/adapter_types.proto\x12\x1ev1.public.fields.adapter_types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xbe\x02\n\x16\x41\x64\x61pterCommonEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12P\n\x05\x65xtra\x18\t \x03(\x0b\x32\x41.v1.public.fields.adapter_types.AdapterCommonEventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x13\x41\x64\x61pterNodeRelation\x12\x10\n\x08\x64\x61tabase\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\r\n\x05\x61lias\x18\x0c \x01(\t\x12\x15\n\rrelation_name\x18\r \x01(\t\"\xc9\x02\n\x0f\x41\x64\x61pterNodeInfo\x12\x11\n\tnode_path\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x11\n\tunique_id\x18\x03 \x01(\t\x12\x15\n\rresource_type\x18\x04 \x01(\t\x12\x14\n\x0cmaterialized\x18\x05 \x01(\t\x12\x13\n\x0bnode_status\x18\x06 \x01(\t\x12\x17\n\x0fnode_started_at\x18\x07 \x01(\t\x12\x18\n\x10node_finished_at\x18\x08 \x01(\t\x12%\n\x04meta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12J\n\rnode_relation\x18\n \x01(\x0b\x32\x33.v1.public.fields.adapter_types.AdapterNodeRelation\x12\x15\n\rnode_checksum\x18\x0b \x01(\t\"G\n\x0fReferenceKeyMsg\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\"?\n\x19\x41\x64\x61pterDeprecationWarning\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\xad\x01\n\x1c\x41\x64\x61pterDeprecationWarningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.adapter_types.AdapterDeprecationWarning\"!\n\x1f\x43ollectFreshnessReturnSignature\"\xb9\x01\n\"CollectFreshnessReturnSignatureMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32?.v1.public.fields.adapter_types.CollectFreshnessReturnSignature\"\xa1\x01\n\x11\x41\x64\x61pterEventDebug\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"\x9d\x01\n\x14\x41\x64\x61pterEventDebugMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.adapter_types.AdapterEventDebug\"\xa0\x01\n\x10\x41\x64\x61pterEventInfo\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"\x9b\x01\n\x13\x41\x64\x61pterEventInfoMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.AdapterEventInfo\"\xa3\x01\n\x13\x41\x64\x61pterEventWarning\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"\xa1\x01\n\x16\x41\x64\x61pterEventWarningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.adapter_types.AdapterEventWarning\"\xb3\x01\n\x11\x41\x64\x61pterEventError\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x10\n\x08\x65xc_info\x18\x05 \x01(\t\"\x9d\x01\n\x14\x41\x64\x61pterEventErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.adapter_types.AdapterEventError\"y\n\rNewConnection\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"\x95\x01\n\x10NewConnectionMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.NewConnection\"=\n\x10\x43onnectionReused\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x16\n\x0eorig_conn_name\x18\x02 \x01(\t\"\x9b\x01\n\x13\x43onnectionReusedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.ConnectionReused\"0\n\x1b\x43onnectionLeftOpenInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"\xb1\x01\n\x1e\x43onnectionLeftOpenInCleanupMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.v1.public.fields.adapter_types.ConnectionLeftOpenInCleanup\".\n\x19\x43onnectionClosedInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"\xad\x01\n\x1c\x43onnectionClosedInCleanupMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.adapter_types.ConnectionClosedInCleanup\"y\n\x0eRollbackFailed\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"\x97\x01\n\x11RollbackFailedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.RollbackFailed\"i\n\x10\x43onnectionClosed\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x9b\x01\n\x13\x43onnectionClosedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.ConnectionClosed\"k\n\x12\x43onnectionLeftOpen\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x9f\x01\n\x15\x43onnectionLeftOpenMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.adapter_types.ConnectionLeftOpen\"a\n\x08Rollback\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x8b\x01\n\x0bRollbackMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.adapter_types.Rollback\"@\n\tCacheMiss\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"\x8d\x01\n\x0c\x43\x61\x63heMissMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.adapter_types.CacheMiss\"u\n\rListRelations\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x42\n\trelations\x18\x03 \x03(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x95\x01\n\x10ListRelationsMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.ListRelations\"z\n\x0e\x43onnectionUsed\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"\x97\x01\n\x11\x43onnectionUsedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.ConnectionUsed\"n\n\x08SQLQuery\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x0b\n\x03sql\x18\x03 \x01(\t\"\x8b\x01\n\x0bSQLQueryMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.adapter_types.SQLQuery\"\x87\x01\n\x0eSQLQueryStatus\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x03 \x01(\x02\x12\x10\n\x08query_id\x18\x04 \x01(\t\"\x97\x01\n\x11SQLQueryStatusMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.SQLQueryStatus\"b\n\tSQLCommit\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x8d\x01\n\x0cSQLCommitMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.adapter_types.SQLCommit\"t\n\rColTypeChange\x12\x11\n\torig_type\x18\x01 \x01(\t\x12\x10\n\x08new_type\x18\x02 \x01(\t\x12>\n\x05table\x18\x03 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x95\x01\n\x10\x43olTypeChangeMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.ColTypeChange\"S\n\x0eSchemaCreation\x12\x41\n\x08relation\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x97\x01\n\x11SchemaCreationMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.SchemaCreation\"O\n\nSchemaDrop\x12\x41\n\x08relation\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x8f\x01\n\rSchemaDropMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.adapter_types.SchemaDrop\"\xaa\x02\n\x0b\x43\x61\x63heAction\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12@\n\x07ref_key\x18\x02 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\x12\x42\n\tref_key_2\x18\x03 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\x12\x42\n\tref_key_3\x18\x04 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\x12\x41\n\x08ref_list\x18\x05 \x03(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x91\x01\n\x0e\x43\x61\x63heActionMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.adapter_types.CacheAction\"\xab\x01\n\x0e\x43\x61\x63heDumpGraph\x12\x46\n\x04\x64ump\x18\x01 \x03(\x0b\x32\x38.v1.public.fields.adapter_types.CacheDumpGraph.DumpEntry\x12\x14\n\x0c\x62\x65\x66ore_after\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x1a+\n\tDumpEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x11\x43\x61\x63heDumpGraphMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.CacheDumpGraph\"B\n\x11\x41\x64\x61pterRegistered\x12\x14\n\x0c\x61\x64\x61pter_name\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x64\x61pter_version\x18\x02 \x01(\t\"\x9d\x01\n\x14\x41\x64\x61pterRegisteredMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.adapter_types.AdapterRegistered\"!\n\x12\x41\x64\x61pterImportError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x9f\x01\n\x15\x41\x64\x61pterImportErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.adapter_types.AdapterImportError\"#\n\x0fPluginLoadError\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"\x99\x01\n\x12PluginLoadErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.adapter_types.PluginLoadError\"t\n\x14NewConnectionOpening\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x18\n\x10\x63onnection_state\x18\x02 \x01(\t\"\xa3\x01\n\x17NewConnectionOpeningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.adapter_types.NewConnectionOpening\"8\n\rCodeExecution\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ode_content\x18\x02 \x01(\t\"\x95\x01\n\x10\x43odeExecutionMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.CodeExecution\"6\n\x13\x43odeExecutionStatus\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x02 \x01(\x02\"\xa1\x01\n\x16\x43odeExecutionStatusMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.adapter_types.CodeExecutionStatus\"%\n\x16\x43\x61talogGenerationError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\xa7\x01\n\x19\x43\x61talogGenerationErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.CatalogGenerationError\"-\n\x13WriteCatalogFailure\x12\x16\n\x0enum_exceptions\x18\x01 \x01(\x05\"\xa1\x01\n\x16WriteCatalogFailureMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.adapter_types.WriteCatalogFailure\"\x1e\n\x0e\x43\x61talogWritten\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x97\x01\n\x11\x43\x61talogWrittenMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.CatalogWritten\"\x14\n\x12\x43\x61nnotGenerateDocs\"\x9f\x01\n\x15\x43\x61nnotGenerateDocsMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.adapter_types.CannotGenerateDocs\"\x11\n\x0f\x42uildingCatalog\"\x99\x01\n\x12\x42uildingCatalogMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.adapter_types.BuildingCatalog\"-\n\x18\x44\x61tabaseErrorRunningHook\x12\x11\n\thook_type\x18\x01 \x01(\t\"\xab\x01\n\x1b\x44\x61tabaseErrorRunningHookMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.adapter_types.DatabaseErrorRunningHook\"4\n\x0cHooksRunning\x12\x11\n\tnum_hooks\x18\x01 \x01(\x05\x12\x11\n\thook_type\x18\x02 \x01(\t\"\x93\x01\n\x0fHooksRunningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.adapter_types.HooksRunning\"T\n\x14\x46inishedRunningStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\x12\x11\n\texecution\x18\x02 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x03 \x01(\x02\"\xa3\x01\n\x17\x46inishedRunningStatsMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.adapter_types.FinishedRunningStats\"<\n\x15\x43onstraintNotEnforced\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"\xa5\x01\n\x18\x43onstraintNotEnforcedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.adapter_types.ConstraintNotEnforced\"=\n\x16\x43onstraintNotSupported\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"\xa7\x01\n\x19\x43onstraintNotSupportedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.ConstraintNotSupported\"%\n\x10TypeCodeNotFound\x12\x11\n\ttype_code\x18\x01 \x01(\x05\"\x9b\x01\n\x13TypeCodeNotFoundMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.TypeCodeNotFoundBAZ?github.com/dbt-labs/proto-golang/v1/public/fields/adapter_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.adapter_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/dbt-labs/proto-golang/v1/public/fields/adapter_types'
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._loaded_options = None
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._loaded_options = None
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_options = b'8\001'
  _globals['_ADAPTERCOMMONEVENTINFO']._serialized_start=150
  _globals['_ADAPTERCOMMONEVENTINFO']._serialized_end=468
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._serialized_start=424
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._serialized_end=468
  _globals['_ADAPTERNODERELATION']._serialized_start=470
  _globals['_ADAPTERNODERELATION']._serialized_end=563
  _globals['_ADAPTERNODEINFO']._serialized_start=566
  _globals['_ADAPTERNODEINFO']._serialized_end=895
  _globals['_REFERENCEKEYMSG']._serialized_start=897
  _globals['_REFERENCEKEYMSG']._serialized_end=968
  _globals['_ADAPTERDEPRECATIONWARNING']._serialized_start=970
  _globals['_ADAPTERDEPRECATIONWARNING']._serialized_end=1033
  _globals['_ADAPTERDEPRECATIONWARNINGMSG']._serialized_start=1036
  _globals['_ADAPTERDEPRECATIONWARNINGMSG']._serialized_end=1209
  _globals['_COLLECTFRESHNESSRETURNSIGNATURE']._serialized_start=1211
  _globals['_COLLECTFRESHNESSRETURNSIGNATURE']._serialized_end=1244
  _globals['_COLLECTFRESHNESSRETURNSIGNATUREMSG']._serialized_start=1247
  _globals['_COLLECTFRESHNESSRETURNSIGNATUREMSG']._serialized_end=1432
  _globals['_ADAPTEREVENTDEBUG']._serialized_start=1435
  _globals['_ADAPTEREVENTDEBUG']._serialized_end=1596
  _globals['_ADAPTEREVENTDEBUGMSG']._serialized_start=1599
  _globals['_ADAPTEREVENTDEBUGMSG']._serialized_end=1756
  _globals['_ADAPTEREVENTINFO']._serialized_start=1759
  _globals['_ADAPTEREVENTINFO']._serialized_end=1919
  _globals['_ADAPTEREVENTINFOMSG']._serialized_start=1922
  _globals['_ADAPTEREVENTINFOMSG']._serialized_end=2077
  _globals['_ADAPTEREVENTWARNING']._serialized_start=2080
  _globals['_ADAPTEREVENTWARNING']._serialized_end=2243
  _globals['_ADAPTEREVENTWARNINGMSG']._serialized_start=2246
  _globals['_ADAPTEREVENTWARNINGMSG']._serialized_end=2407
  _globals['_ADAPTEREVENTERROR']._serialized_start=2410
  _globals['_ADAPTEREVENTERROR']._serialized_end=2589
  _globals['_ADAPTEREVENTERRORMSG']._serialized_start=2592
  _globals['_ADAPTEREVENTERRORMSG']._serialized_end=2749
  _globals['_NEWCONNECTION']._serialized_start=2751
  _globals['_NEWCONNECTION']._serialized_end=2872
  _globals['_NEWCONNECTIONMSG']._serialized_start=2875
  _globals['_NEWCONNECTIONMSG']._serialized_end=3024
  _globals['_CONNECTIONREUSED']._serialized_start=3026
  _globals['_CONNECTIONREUSED']._serialized_end=3087
  _globals['_CONNECTIONREUSEDMSG']._serialized_start=3090
  _globals['_CONNECTIONREUSEDMSG']._serialized_end=3245
  _globals['_CONNECTIONLEFTOPENINCLEANUP']._serialized_start=3247
  _globals['_CONNECTIONLEFTOPENINCLEANUP']._serialized_end=3295
  _globals['_CONNECTIONLEFTOPENINCLEANUPMSG']._serialized_start=3298
  _globals['_CONNECTIONLEFTOPENINCLEANUPMSG']._serialized_end=3475
  _globals['_CONNECTIONCLOSEDINCLEANUP']._serialized_start=3477
  _globals['_CONNECTIONCLOSEDINCLEANUP']._serialized_end=3523
  _globals['_CONNECTIONCLOSEDINCLEANUPMSG']._serialized_start=3526
  _globals['_CONNECTIONCLOSEDINCLEANUPMSG']._serialized_end=3699
  _globals['_ROLLBACKFAILED']._serialized_start=3701
  _globals['_ROLLBACKFAILED']._serialized_end=3822
  _globals['_ROLLBACKFAILEDMSG']._serialized_start=3825
  _globals['_ROLLBACKFAILEDMSG']._serialized_end=3976
  _globals['_CONNECTIONCLOSED']._serialized_start=3978
  _globals['_CONNECTIONCLOSED']._serialized_end=4083
  _globals['_CONNECTIONCLOSEDMSG']._serialized_start=4086
  _globals['_CONNECTIONCLOSEDMSG']._serialized_end=4241
  _globals['_CONNECTIONLEFTOPEN']._serialized_start=4243
  _globals['_CONNECTIONLEFTOPEN']._serialized_end=4350
  _globals['_CONNECTIONLEFTOPENMSG']._serialized_start=4353
  _globals['_CONNECTIONLEFTOPENMSG']._serialized_end=4512
  _globals['_ROLLBACK']._serialized_start=4514
  _globals['_ROLLBACK']._serialized_end=4611
  _globals['_ROLLBACKMSG']._serialized_start=4614
  _globals['_ROLLBACKMSG']._serialized_end=4753
  _globals['_CACHEMISS']._serialized_start=4755
  _globals['_CACHEMISS']._serialized_end=4819
  _globals['_CACHEMISSMSG']._serialized_start=4822
  _globals['_CACHEMISSMSG']._serialized_end=4963
  _globals['_LISTRELATIONS']._serialized_start=4965
  _globals['_LISTRELATIONS']._serialized_end=5082
  _globals['_LISTRELATIONSMSG']._serialized_start=5085
  _globals['_LISTRELATIONSMSG']._serialized_end=5234
  _globals['_CONNECTIONUSED']._serialized_start=5236
  _globals['_CONNECTIONUSED']._serialized_end=5358
  _globals['_CONNECTIONUSEDMSG']._serialized_start=5361
  _globals['_CONNECTIONUSEDMSG']._serialized_end=5512
  _globals['_SQLQUERY']._serialized_start=5514
  _globals['_SQLQUERY']._serialized_end=5624
  _globals['_SQLQUERYMSG']._serialized_start=5627
  _globals['_SQLQUERYMSG']._serialized_end=5766
  _globals['_SQLQUERYSTATUS']._serialized_start=5769
  _globals['_SQLQUERYSTATUS']._serialized_end=5904
  _globals['_SQLQUERYSTATUSMSG']._serialized_start=5907
  _globals['_SQLQUERYSTATUSMSG']._serialized_end=6058
  _globals['_SQLCOMMIT']._serialized_start=6060
  _globals['_SQLCOMMIT']._serialized_end=6158
  _globals['_SQLCOMMITMSG']._serialized_start=6161
  _globals['_SQLCOMMITMSG']._serialized_end=6302
  _globals['_COLTYPECHANGE']._serialized_start=6304
  _globals['_COLTYPECHANGE']._serialized_end=6420
  _globals['_COLTYPECHANGEMSG']._serialized_start=6423
  _globals['_COLTYPECHANGEMSG']._serialized_end=6572
  _globals['_SCHEMACREATION']._serialized_start=6574
  _globals['_SCHEMACREATION']._serialized_end=6657
  _globals['_SCHEMACREATIONMSG']._serialized_start=6660
  _globals['_SCHEMACREATIONMSG']._serialized_end=6811
  _globals['_SCHEMADROP']._serialized_start=6813
  _globals['_SCHEMADROP']._serialized_end=6892
  _globals['_SCHEMADROPMSG']._serialized_start=6895
  _globals['_SCHEMADROPMSG']._serialized_end=7038
  _globals['_CACHEACTION']._serialized_start=7041
  _globals['_CACHEACTION']._serialized_end=7339
  _globals['_CACHEACTIONMSG']._serialized_start=7342
  _globals['_CACHEACTIONMSG']._serialized_end=7487
  _globals['_CACHEDUMPGRAPH']._serialized_start=7490
  _globals['_CACHEDUMPGRAPH']._serialized_end=7661
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_start=7618
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_end=7661
  _globals['_CACHEDUMPGRAPHMSG']._serialized_start=7664
  _globals['_CACHEDUMPGRAPHMSG']._serialized_end=7815
  _globals['_ADAPTERREGISTERED']._serialized_start=7817
  _globals['_ADAPTERREGISTERED']._serialized_end=7883
  _globals['_ADAPTERREGISTEREDMSG']._serialized_start=7886
  _globals['_ADAPTERREGISTEREDMSG']._serialized_end=8043
  _globals['_ADAPTERIMPORTERROR']._serialized_start=8045
  _globals['_ADAPTERIMPORTERROR']._serialized_end=8078
  _globals['_ADAPTERIMPORTERRORMSG']._serialized_start=8081
  _globals['_ADAPTERIMPORTERRORMSG']._serialized_end=8240
  _globals['_PLUGINLOADERROR']._serialized_start=8242
  _globals['_PLUGINLOADERROR']._serialized_end=8277
  _globals['_PLUGINLOADERRORMSG']._serialized_start=8280
  _globals['_PLUGINLOADERRORMSG']._serialized_end=8433
  _globals['_NEWCONNECTIONOPENING']._serialized_start=8435
  _globals['_NEWCONNECTIONOPENING']._serialized_end=8551
  _globals['_NEWCONNECTIONOPENINGMSG']._serialized_start=8554
  _globals['_NEWCONNECTIONOPENINGMSG']._serialized_end=8717
  _globals['_CODEEXECUTION']._serialized_start=8719
  _globals['_CODEEXECUTION']._serialized_end=8775
  _globals['_CODEEXECUTIONMSG']._serialized_start=8778
  _globals['_CODEEXECUTIONMSG']._serialized_end=8927
  _globals['_CODEEXECUTIONSTATUS']._serialized_start=8929
  _globals['_CODEEXECUTIONSTATUS']._serialized_end=8983
  _globals['_CODEEXECUTIONSTATUSMSG']._serialized_start=8986
  _globals['_CODEEXECUTIONSTATUSMSG']._serialized_end=9147
  _globals['_CATALOGGENERATIONERROR']._serialized_start=9149
  _globals['_CATALOGGENERATIONERROR']._serialized_end=9186
  _globals['_CATALOGGENERATIONERRORMSG']._serialized_start=9189
  _globals['_CATALOGGENERATIONERRORMSG']._serialized_end=9356
  _globals['_WRITECATALOGFAILURE']._serialized_start=9358
  _globals['_WRITECATALOGFAILURE']._serialized_end=9403
  _globals['_WRITECATALOGFAILUREMSG']._serialized_start=9406
  _globals['_WRITECATALOGFAILUREMSG']._serialized_end=9567
  _globals['_CATALOGWRITTEN']._serialized_start=9569
  _globals['_CATALOGWRITTEN']._serialized_end=9599
  _globals['_CATALOGWRITTENMSG']._serialized_start=9602
  _globals['_CATALOGWRITTENMSG']._serialized_end=9753
  _globals['_CANNOTGENERATEDOCS']._serialized_start=9755
  _globals['_CANNOTGENERATEDOCS']._serialized_end=9775
  _globals['_CANNOTGENERATEDOCSMSG']._serialized_start=9778
  _globals['_CANNOTGENERATEDOCSMSG']._serialized_end=9937
  _globals['_BUILDINGCATALOG']._serialized_start=9939
  _globals['_BUILDINGCATALOG']._serialized_end=9956
  _globals['_BUILDINGCATALOGMSG']._serialized_start=9959
  _globals['_BUILDINGCATALOGMSG']._serialized_end=10112
  _globals['_DATABASEERRORRUNNINGHOOK']._serialized_start=10114
  _globals['_DATABASEERRORRUNNINGHOOK']._serialized_end=10159
  _globals['_DATABASEERRORRUNNINGHOOKMSG']._serialized_start=10162
  _globals['_DATABASEERRORRUNNINGHOOKMSG']._serialized_end=10333
  _globals['_HOOKSRUNNING']._serialized_start=10335
  _globals['_HOOKSRUNNING']._serialized_end=10387
  _globals['_HOOKSRUNNINGMSG']._serialized_start=10390
  _globals['_HOOKSRUNNINGMSG']._serialized_end=10537
  _globals['_FINISHEDRUNNINGSTATS']._serialized_start=10539
  _globals['_FINISHEDRUNNINGSTATS']._serialized_end=10623
  _globals['_FINISHEDRUNNINGSTATSMSG']._serialized_start=10626
  _globals['_FINISHEDRUNNINGSTATSMSG']._serialized_end=10789
  _globals['_CONSTRAINTNOTENFORCED']._serialized_start=10791
  _globals['_CONSTRAINTNOTENFORCED']._serialized_end=10851
  _globals['_CONSTRAINTNOTENFORCEDMSG']._serialized_start=10854
  _globals['_CONSTRAINTNOTENFORCEDMSG']._serialized_end=11019
  _globals['_CONSTRAINTNOTSUPPORTED']._serialized_start=11021
  _globals['_CONSTRAINTNOTSUPPORTED']._serialized_end=11082
  _globals['_CONSTRAINTNOTSUPPORTEDMSG']._serialized_start=11085
  _globals['_CONSTRAINTNOTSUPPORTEDMSG']._serialized_end=11252
  _globals['_TYPECODENOTFOUND']._serialized_start=11254
  _globals['_TYPECODENOTFOUND']._serialized_end=11291
  _globals['_TYPECODENOTFOUNDMSG']._serialized_start=11294
  _globals['_TYPECODENOTFOUNDMSG']._serialized_end=11449
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/mcp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2
from dbtlabs.proto.public.v1.common import vortex_telemetry_contexts_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__telemetry__contexts__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dbtlabs/proto/public/v1/events/mcp.proto\x12\x14v1.public.events.mcp\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\x1a>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xcc\x05\n\nToolCalled\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rstart_time_ms\x18\x03 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x04 \x01(\x03\x12\x11\n\ttool_name\x18\x05 \x01(\t\x12\x42\n\targuments\x18\x06 \x03(\x0b\x32/.v1.public.events.mcp.ToolCalled.ArgumentsEntry\x12\x15\n\rerror_message\x18\x07 \x01(\t\x12$\n\x1c\x64\x62t_cloud_environment_id_dev\x18\x08 \x01(\t\x12%\n\x1d\x64\x62t_cloud_environment_id_prod\x18\t \x01(\t\x12\x19\n\x11\x64\x62t_cloud_user_id\x18\n \x01(\t\x12\x15\n\rlocal_user_id\x18\x0b \x01(\t\x12\x0c\n\x04host\x18\x0c \x01(\t\x12 \n\x18multicell_account_prefix\x18\r \x01(\t\x12W\n\x03\x63tx\x18\x0e \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x17\n\x0f\x64\x62t_mcp_version\x18\x0f \x01(\t\x12\x1d\n\x15\x61uthentication_method\x18\x10 \x01(\t\x12\x10\n\x08trace_id\x18\x11 \x01(\t\x12\x19\n\x11\x64isabled_toolsets\x18\x12 \x03(\t\x12\x16\n\x0e\x64isabled_tools\x18\x13 \x03(\t\x12\x12\n\nuser_agent\x18\x14 \x01(\t\x1a\x30\n\x0e\x41rgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42\x37Z5github.com/dbt-labs/proto-golang/v1/public/events/mcpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.mcp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/dbt-labs/proto-golang/v1/public/events/mcp'
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._loaded_options = None
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._serialized_options = b'8\001'
  _globals['_TOOLCALLED']._loaded_options = None
  _globals['_TOOLCALLED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_TOOLCALLED']._serialized_start=259
  _globals['_TOOLCALLED']._serialized_end=975
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._serialized_start=917
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._serialized_end=965
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SeverityNumber:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SeverityNumberEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SeverityNumber.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SEVERITY_NUMBER_UNSPECIFIED: _SeverityNumber.ValueType  # 0
    """Default value. Should not be used."""
    SEVERITY_NUMBER_TRACE: _SeverityNumber.ValueType  # 1
    SEVERITY_NUMBER_DEBUG: _SeverityNumber.ValueType  # 5
    SEVERITY_NUMBER_INFO: _SeverityNumber.ValueType  # 9
    SEVERITY_NUMBER_WARN: _SeverityNumber.ValueType  # 13
    SEVERITY_NUMBER_ERROR: _SeverityNumber.ValueType  # 17

class SeverityNumber(_SeverityNumber, metaclass=_SeverityNumberEnumTypeWrapper):
    """Subset of OTLP LogRecord.SeverityNumber used by fusion."""

SEVERITY_NUMBER_UNSPECIFIED: SeverityNumber.ValueType  # 0
"""Default value. Should not be used."""
SEVERITY_NUMBER_TRACE: SeverityNumber.ValueType  # 1
SEVERITY_NUMBER_DEBUG: SeverityNumber.ValueType  # 5
SEVERITY_NUMBER_INFO: SeverityNumber.ValueType  # 9
SEVERITY_NUMBER_WARN: SeverityNumber.ValueType  # 13
SEVERITY_NUMBER_ERROR: SeverityNumber.ValueType  # 17
Global___SeverityNumber: typing_extensions.TypeAlias = SeverityNumber



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ListOutputFormat:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ListOutputFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ListOutputFormat.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LIST_OUTPUT_FORMAT_UNSPECIFIED: _ListOutputFormat.ValueType  # 0
    LIST_OUTPUT_FORMAT_JSON: _ListOutputFormat.ValueType  # 1
    LIST_OUTPUT_FORMAT_SELECTOR: _ListOutputFormat.ValueType  # 2
    LIST_OUTPUT_FORMAT_NAME: _ListOutputFormat.ValueType  # 3
    LIST_OUTPUT_FORMAT_PATH: _ListOutputFormat.ValueType  # 4

class ListOutputFormat(_ListOutputFormat, metaclass=_ListOutputFormatEnumTypeWrapper):
    """Output format for list command"""

LIST_OUTPUT_FORMAT_UNSPECIFIED: ListOutputFormat.ValueType  # 0
LIST_OUTPUT_FORMAT_JSON: ListOutputFormat.ValueType  # 1
LIST_OUTPUT_FORMAT_SELECTOR: ListOutputFormat.ValueType  # 2
LIST_OUTPUT_FORMAT_NAME: ListOutputFormat.ValueType  # 3
LIST_OUTPUT_FORMAT_PATH: ListOutputFormat.ValueType  # 4
Global___ListOutputFormat: typing_extensions.TypeAlias = ListOutputFormat

@typing.final
class ListItemOutput(google.protobuf.message.Message):
    """Event emitted for each item in a list command output.
    This event replaces the dbt-core PrintEvent (Z052) for list operations.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    output_format: Global___ListOutputFormat.ValueType
    """Format of the output"""
    content: builtins.str
    """The actual content of the list item being displayed"""
    unique_id: builtins.str
    """The unique_id of the node being listed (e.g., "model.my_project.my_model")"""
    def __init__(
        self,
        *,
        output_format: Global___ListOutputFormat.ValueType = ...,
        content: builtins.str = ...,
        unique_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "content", b"content", "output_format", b"output_format", "unique_id", b"unique_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___ListItemOutput: typing_extensions.TypeAlias = ListItemOutput



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/phase/phase.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/fusion/phase/phase.proto\x12\x1dv1.public.events.fusion.phase\"\xed\x01\n\rPhaseExecuted\x12<\n\x05phase\x18\x01 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhase\x12\x1d\n\x10node_count_total\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1f\n\x12node_count_skipped\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x1d\n\x10node_count_error\x18\x04 \x01(\x04H\x02\x88\x01\x01\x42\x13\n\x11_node_count_totalB\x15\n\x13_node_count_skippedB\x13\n\x11_node_count_error*\x8f\x04\n\x0e\x45xecutionPhase\x12\x1f\n\x1b\x45XECUTION_PHASE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45XECUTION_PHASE_CLEAN\x10\n\x12 \n\x1c\x45XECUTION_PHASE_LOAD_PROJECT\x10\x14\x12\x19\n\x15\x45XECUTION_PHASE_PARSE\x10\x1e\x12\x1c\n\x18\x45XECUTION_PHASE_SCHEDULE\x10(\x12\x1b\n\x17\x45XECUTION_PHASE_COMPARE\x10-\x12 \n\x1c\x45XECUTION_PHASE_INIT_ADAPTER\x10\x32\x12#\n\x1f\x45XECUTION_PHASE_DEFER_HYDRATION\x10<\x12$\n EXECUTION_PHASE_TASK_GRAPH_BUILD\x10\x46\x12(\n$EXECUTION_PHASE_NODE_CACHE_HYDRATION\x10P\x12\x1a\n\x16\x45XECUTION_PHASE_RENDER\x10Z\x12\x1b\n\x17\x45XECUTION_PHASE_ANALYZE\x10\x64\x12\x17\n\x13\x45XECUTION_PHASE_RUN\x10n\x12&\n\"EXECUTION_PHASE_FRESHNESS_ANALYSIS\x10x\x12\x1c\n\x17\x45XECUTION_PHASE_LINEAGE\x10\x82\x01\x12\x1a\n\x15\x45XECUTION_PHASE_DEBUG\x10\x8c\x01\x42@Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/phaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/phase'
  _globals['_EXECUTIONPHASE']._serialized_start=331
  _globals['_EXECUTIONPHASE']._serialized_end=858
  _globals['_PHASEEXECUTED']._serialized_start=91
  _globals['_PHASEEXECUTED']._serialized_end=328
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.fusion.compat.otlp_pb2
import dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogMessage(google.protobuf.message.Message):
    """Generic event for log messages that do not cary special meaning
    or additional metadata beyond the standard fields
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    ORIGINAL_SEVERITY_NUMBER_FIELD_NUMBER: builtins.int
    ORIGINAL_SEVERITY_TEXT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    code: builtins.int
    """Optional fusion error/warning code"""
    dbt_core_event_code: builtins.str
    """Optional legacy dbt-core code (e.g. "Z048") if this event has a strict mapping to a dbt core event."""
    original_severity_number: dbtlabs.proto.public.v1.events.fusion.compat.otlp_pb2.SeverityNumber.ValueType
    """Original severity before user up/down-grade configuration applied."""
    original_severity_text: builtins.str
    unique_id: builtins.str
    """If this log message is emitted in the context of a specific node,
    this field should be set to the node's unique FQN.
    """
    file: builtins.str
    """Fusion source code file name where the log was created. Only available in debug builds."""
    line: builtins.int
    """Fusion source code file line number where the log was created. Only available in debug builds."""
    phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType
    """Execution phase (if known) during which this log was emitted."""
    package_name: builtins.str
    """Package name of the project dependency for which this log was emitted. Not set for the root project."""
    def __init__(
        self,
        *,
        code: builtins.int | None = ...,
        dbt_core_event_code: builtins.str | None = ...,
        original_severity_number: dbtlabs.proto.public.v1.events.fusion.compat.otlp_pb2.SeverityNumber.ValueType = ...,
        original_severity_text: builtins.str = ...,
        unique_id: builtins.str | None = ...,
        file: builtins.str | None = ...,
        line: builtins.int | None = ...,
        phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType | None = ...,
        package_name: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_code", b"_code", "_dbt_core_event_code", b"_dbt_core_event_code", "_file", b"_file", "_line", b"_line", "_package_name", b"_package_name", "_phase", b"_phase", "_unique_id", b"_unique_id", "code", b"code", "dbt_core_event_code", b"dbt_core_event_code", "file", b"file", "line", b"line", "package_name", b"package_name", "phase", b"phase", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_code", b"_code", "_dbt_core_event_code", b"_dbt_core_event_code", "_file", b"_file", "_line", b"_line", "_package_name", b"_package_name", "_phase", b"_phase", "_unique_id", b"_unique_id", "code", b"code", "dbt_core_event_code", b"dbt_core_event_code", "file", b"file", "line", b"line", "original_severity_number", b"original_severity_number", "original_severity_text", b"original_severity_text", "package_name", b"package_name", "phase", b"phase", "unique_id", b"unique_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_code", b"_code"]) -> typing.Literal["code"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_dbt_core_event_code", b"_dbt_core_event_code"]) -> typing.Literal["dbt_core_event_code"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_file", b"_file"]) -> typing.Literal["file"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_line", b"_line"]) -> typing.Literal["line"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_package_name", b"_package_name"]) -> typing.Literal["package_name"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_phase", b"_phase"]) -> typing.Literal["phase"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___LogMessage: typing_extensions.TypeAlias = LogMessage

@typing.final
class UserLogMessage(google.protobuf.message.Message):
    """Event emitted when user explicitly logs messages via jinja's print() or log() functions.
    This event maps to dbt-core's JinjaLogInfo (I061-I063) events.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_PRINT_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    COLUMN_FIELD_NUMBER: builtins.int
    RELATIVE_PATH_FIELD_NUMBER: builtins.int
    is_print: builtins.bool
    """True if this message was emitted via print(), false if via log()"""
    dbt_core_event_code: builtins.str
    """Legacy dbt-core event code:
    - "I062" (JinjaLogInfo) for log info level
    - "I063" (JinjaLogDebug) for log debug level
    - "I061" (JinjaLogWarning) for log warning level
    - "Z052" (PrintEvent) for print statements
    """
    unique_id: builtins.str
    """If this log message is emitted in the context of a specific node,
    this field should be set to the node's unique FQN.
    """
    phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType
    """Execution phase (if known) during which this log was emitted."""
    package_name: builtins.str
    """Package name (project or dependency) from which this log was emitted."""
    line: builtins.int
    """Location within the SQL/Jinja file where print() or log() was called.
    Line number (1-indexed) of the print/log call in the SQL file.
    """
    column: builtins.int
    """Column number (0-indexed) of the print/log call in the SQL file."""
    relative_path: builtins.str
    """Relative path to the SQL file containing the print/log call."""
    def __init__(
        self,
        *,
        is_print: builtins.bool = ...,
        dbt_core_event_code: builtins.str = ...,
        unique_id: builtins.str | None = ...,
        phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType | None = ...,
        package_name: builtins.str | None = ...,
        line: builtins.int | None = ...,
        column: builtins.int | None = ...,
        relative_path: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_column", b"_column", "_line", b"_line", "_package_name", b"_package_name", "_phase", b"_phase", "_relative_path", b"_relative_path", "_unique_id", b"_unique_id", "column", b"column", "line", b"line", "package_name", b"package_name", "phase", b"phase", "relative_path", b"relative_path", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_column", b"_column", "_line", b"_line", "_package_name", b"_package_name", "_phase", b"_phase", "_relative_path", b"_relative_path", "_unique_id", b"_unique_id", "column", b"column", "dbt_core_event_code", b"dbt_core_event_code", "is_print", b"is_print", "line", b"line", "package_name", b"package_name", "phase", b"phase", "relative_path", b"relative_path", "unique_id", b"unique_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_column", b"_column"]) -> typing.Literal["column"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_line", b"_line"]) -> typing.Literal["line"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_package_name", b"_package_name"]) -> typing.Literal["package_name"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_phase", b"_phase"]) -> typing.Literal["phase"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_relative_path", b"_relative_path"]) -> typing.Literal["relative_path"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___UserLogMessage: typing_extensions.TypeAlias = UserLogMessage



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2
import dbtlabs.proto.public.v1.events.vortex_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PageLoad(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___PageLoad: typing_extensions.TypeAlias = PageLoad

@typing.final
class CatalogLiteOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___CatalogLiteOpen: typing_extensions.TypeAlias = CatalogLiteOpen

@typing.final
class QueryHistoryOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___QueryHistoryOpen: typing_extensions.TypeAlias = QueryHistoryOpen

@typing.final
class BookmarksOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___BookmarksOpen: typing_extensions.TypeAlias = BookmarksOpen

@typing.final
class BookmarksOpenDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___BookmarksOpenDetails: typing_extensions.TypeAlias = BookmarksOpenDetails

@typing.final
class BookmarksEditDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___BookmarksEditDetails: typing_extensions.TypeAlias = BookmarksEditDetails

@typing.final
class VersionHistoryOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___VersionHistoryOpen: typing_extensions.TypeAlias = VersionHistoryOpen

@typing.final
class CopilotOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___CopilotOpen: typing_extensions.TypeAlias = CopilotOpen

@typing.final
class CopilotCreateChat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___CopilotCreateChat: typing_extensions.TypeAlias = CopilotCreateChat

@typing.final
class CopilotAddCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    COPILOT_REQUEST_ID_FIELD_NUMBER: builtins.int
    copilot_request_id: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        copilot_request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["copilot_request_id", b"copilot_request_id", "ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___CopilotAddCode: typing_extensions.TypeAlias = CopilotAddCode

@typing.final
class CopilotFeedbackGood(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    COPILOT_REQUEST_ID_FIELD_NUMBER: builtins.int
    copilot_request_id: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        copilot_request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["copilot_request_id", b"copilot_request_id", "ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___CopilotFeedbackGood: typing_extensions.TypeAlias = CopilotFeedbackGood

@typing.final
class CopilotFeedbackBad(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    COPILOT_REQUEST_ID_FIELD_NUMBER: builtins.int
    copilot_request_id: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        copilot_request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["copilot_request_id", b"copilot_request_id", "ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___CopilotFeedbackBad: typing_extensions.TypeAlias = CopilotFeedbackBad

@typing.final
class ChartsOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___ChartsOpen: typing_extensions.TypeAlias = ChartsOpen

@typing.final
class ChartsConfigOpen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___ChartsConfigOpen: typing_extensions.TypeAlias = ChartsConfigOpen

@typing.final
class ShareCreateLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___ShareCreateLink: typing_extensions.TypeAlias = ShareCreateLink

@typing.final
class ShareOpenLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___ShareOpenLink: typing_extensions.TypeAlias = ShareOpenLink

@typing.final
class ShareCopyToNewQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___ShareCopyToNewQuery: typing_extensions.TypeAlias = ShareCopyToNewQuery

@typing.final
class CsvDownload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    FILE_SIZE_BYTES_FIELD_NUMBER: builtins.int
    file_size_bytes: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        file_size_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment", "file_size_bytes", b"file_size_bytes"]) -> None: ...

Global___CsvDownload: typing_extensions.TypeAlias = CsvDownload

@typing.final
class RunQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    sql: builtins.str
    error: builtins.str
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def context(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        context: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        sql: builtins.str = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["context", b"context", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["context", b"context", "enrichment", b"enrichment", "error", b"error", "sql", b"sql"]) -> None: ...

Global___RunQuery: typing_extensions.TypeAlias = RunQuery

@typing.final
class HandoffOpenSqlInStudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___HandoffOpenSqlInStudio: typing_extensions.TypeAlias = HandoffOpenSqlInStudio

@typing.final
class HandoffOpenSqlInCanvas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___HandoffOpenSqlInCanvas: typing_extensions.TypeAlias = HandoffOpenSqlInCanvas

@typing.final
class HandoffOpenModelInCatalog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___HandoffOpenModelInCatalog: typing_extensions.TypeAlias = HandoffOpenModelInCatalog

@typing.final
class Acknowledge2025LaunchTrialBanner(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> None: ...

Global___Acknowledge2025LaunchTrialBanner: typing_extensions.TypeAlias = Acknowledge2025LaunchTrialBanner



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _QueryOutcome:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _QueryOutcomeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_QueryOutcome.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    QUERY_OUTCOME_UNSPECIFIED: _QueryOutcome.ValueType  # 0
    """Default value. Should only be set on unfinished spans"""
    QUERY_OUTCOME_SUCCESS: _QueryOutcome.ValueType  # 1
    """Successfully executed the query."""
    QUERY_OUTCOME_ERROR: _QueryOutcome.ValueType  # 2
    """Failed with an error type (individual errors reported as separate events).
    If set, `node_error_type` with also be set to indicate the type of error.
    """
    QUERY_OUTCOME_CANCELED: _QueryOutcome.ValueType  # 3
    """Query was canceled (e.g. user-initiated cancellation)."""

class QueryOutcome(_QueryOutcome, metaclass=_QueryOutcomeEnumTypeWrapper):
    """Outcome of a query execution"""

QUERY_OUTCOME_UNSPECIFIED: QueryOutcome.ValueType  # 0
"""Default value. Should only be set on unfinished spans"""
QUERY_OUTCOME_SUCCESS: QueryOutcome.ValueType  # 1
"""Successfully executed the query."""
QUERY_OUTCOME_ERROR: QueryOutcome.ValueType  # 2
"""Failed with an error type (individual errors reported as separate events).
If set, `node_error_type` with also be set to indicate the type of error.
"""
QUERY_OUTCOME_CANCELED: QueryOutcome.ValueType  # 3
"""Query was canceled (e.g. user-initiated cancellation)."""
Global___QueryOutcome: typing_extensions.TypeAlias = QueryOutcome

@typing.final
class QueryExecuted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_FIELD_NUMBER: builtins.int
    SQL_HASH_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    QUERY_DESCRIPTION_FIELD_NUMBER: builtins.int
    QUERY_ID_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    QUERY_OUTCOME_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    QUERY_ERROR_ADAPTER_MESSAGE_FIELD_NUMBER: builtins.int
    QUERY_ERROR_VENDOR_CODE_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    sql: builtins.str
    """Raw SQL string that was executed. May be obfuscated."""
    sql_hash: builtins.str
    """Blake3, 16-bytes hash of the raw SQL string encoded as hex."""
    adapter_type: builtins.str
    """Type of the adapter (e.g. "snowflake", "bigquery", "postgres", etc.)"""
    query_description: builtins.str
    """Optional human-readable description of the query."""
    query_id: builtins.str
    """Database provided query ID for the executed query, if available."""
    unique_id: builtins.str
    """unique_id of the node that generated this query. Some queries may not be associated with a single node."""
    query_outcome: Global___QueryOutcome.ValueType
    """Outcome for this query execution."""
    phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType
    """Execution phase during which this query was evaluated, if available"""
    query_error_adapter_message: builtins.str
    """Granular error information for failed queries.

    Arbitrary adapter defined error message
    """
    query_error_vendor_code: builtins.int
    """Arbitrary adapter (vendor) defined error code"""
    dbt_core_event_code: builtins.str
    """Legacy dbt core event code: E016 or E017"""
    def __init__(
        self,
        *,
        sql: builtins.str = ...,
        sql_hash: builtins.str = ...,
        adapter_type: builtins.str = ...,
        query_description: builtins.str | None = ...,
        query_id: builtins.str | None = ...,
        unique_id: builtins.str | None = ...,
        query_outcome: Global___QueryOutcome.ValueType = ...,
        phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType | None = ...,
        query_error_adapter_message: builtins.str | None = ...,
        query_error_vendor_code: builtins.int | None = ...,
        dbt_core_event_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_phase", b"_phase", "_query_description", b"_query_description", "_query_error_adapter_message", b"_query_error_adapter_message", "_query_error_vendor_code", b"_query_error_vendor_code", "_query_id", b"_query_id", "_unique_id", b"_unique_id", "phase", b"phase", "query_description", b"query_description", "query_error_adapter_message", b"query_error_adapter_message", "query_error_vendor_code", b"query_error_vendor_code", "query_id", b"query_id", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_phase", b"_phase", "_query_description", b"_query_description", "_query_error_adapter_message", b"_query_error_adapter_message", "_query_error_vendor_code", b"_query_error_vendor_code", "_query_id", b"_query_id", "_unique_id", b"_unique_id", "adapter_type", b"adapter_type", "dbt_core_event_code", b"dbt_core_event_code", "phase", b"phase", "query_description", b"query_description", "query_error_adapter_message", b"query_error_adapter_message", "query_error_vendor_code", b"query_error_vendor_code", "query_id", b"query_id", "query_outcome", b"query_outcome", "sql", b"sql", "sql_hash", b"sql_hash", "unique_id", b"unique_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_phase", b"_phase"]) -> typing.Literal["phase"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_query_description", b"_query_description"]) -> typing.Literal["query_description"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_query_error_adapter_message", b"_query_error_adapter_message"]) -> typing.Literal["query_error_adapter_message"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_query_error_vendor_code", b"_query_error_vendor_code"]) -> typing.Literal["query_error_vendor_code"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_query_id", b"_query_id"]) -> typing.Literal["query_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___QueryExecuted: typing_extensions.TypeAlias = QueryExecuted



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events import fusion_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAdbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto\x12\"v1.public.events.fusion.onboarding\x1a+dbtlabs/proto/public/v1/events/fusion.proto\"R\n\x15OnboardingScreenShown\x12\x39\n\x06screen\x18\x01 \x01(\x0e\x32).v1.public.events.fusion.OnboardingScreenBEZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboardingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.onboarding.onboarding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboarding'
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_start=150
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_end=232
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/dev/dev.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3dbtlabs/proto/public/v1/events/fusion/dev/dev.proto\x12\x1bv1.public.events.fusion.dev\"[\n\nDebugValue\x12\x11\n\x07\x66loat64\x18\x01 \x01(\x01H\x00\x12\x0e\n\x04\x62ool\x18\x04 \x01(\x08H\x00\x12\x10\n\x06string\x18\x05 \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\x06 \x01(\x0cH\x00\x42\x07\n\x05value\"\xea\x01\n\tCallTrace\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x04\x66ile\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04line\x18\x03 \x01(\rH\x01\x88\x01\x01\x12@\n\x05\x65xtra\x18\x04 \x03(\x0b\x32\x31.v1.public.events.fusion.dev.CallTrace.ExtraEntry\x1aU\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.v1.public.events.fusion.dev.DebugValue:\x02\x38\x01\x42\x07\n\x05_fileB\x07\n\x05_line\"3\n\x07Unknown\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0c\n\x04line\x18\x03 \x01(\rB>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/devb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.dev.dev_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/dev'
  _globals['_CALLTRACE_EXTRAENTRY']._loaded_options = None
  _globals['_CALLTRACE_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_DEBUGVALUE']._serialized_start=84
  _globals['_DEBUGVALUE']._serialized_end=175
  _globals['_CALLTRACE']._serialized_start=178
  _globals['_CALLTRACE']._serialized_end=412
  _globals['_CALLTRACE_EXTRAENTRY']._serialized_start=309
  _globals['_CALLTRACE_EXTRAENTRY']._serialized_end=394
  _globals['_UNKNOWN']._serialized_start=414
  _globals['_UNKNOWN']._serialized_end=465
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/fusion.proto\x12\x17v1.public.events.fusion\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xb0\x01\n\x0b\x41\x64\x61pterInfo\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x04 \x01(\t\x12\x19\n\x11\x61\x64\x61pter_unique_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xe9\x02\n\rAdapterInfoV2\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x14\n\x0crun_model_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_name\x18\x04 \x01(\t\x12\x1c\n\x14\x62\x61se_adapter_version\x18\x05 \x01(\t\x12\x17\n\x0f\x61\x64\x61pter_version\x18\x06 \x01(\t\x12^\n\x15model_adapter_details\x18\x07 \x03(\x0b\x32?.v1.public.events.fusion.AdapterInfoV2.ModelAdapterDetailsEntry\x1a:\n\x18ModelAdapterDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x84\x02\n\nInvocation\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x06 \x01(\t\x12\x10\n\x08progress\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x13\n\x0bresult_type\x18\t \x01(\t\x12\x16\n\x0egit_commit_sha\x18\n \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x96\x01\n\rInvocationEnv\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb1\x01\n\x0ePackageInstall\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x82\x03\n\x0eResourceCounts\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x0e\n\x06models\x18\x04 \x01(\x05\x12\r\n\x05tests\x18\x05 \x01(\x05\x12\x11\n\tsnapshots\x18\x06 \x01(\x05\x12\x10\n\x08\x61nalyses\x18\x07 \x01(\x05\x12\x0e\n\x06macros\x18\x08 \x01(\x05\x12\x12\n\noperations\x18\t \x01(\x05\x12\r\n\x05seeds\x18\n \x01(\x05\x12\x0f\n\x07sources\x18\x0b \x01(\x05\x12\x11\n\texposures\x18\x0c \x01(\x05\x12\x0f\n\x07metrics\x18\r \x01(\x05\x12\x0e\n\x06groups\x18\x0e \x01(\x05\x12\x12\n\nunit_tests\x18\x0f \x01(\x05\x12\x17\n\x0fsemantic_models\x18\x10 \x01(\x05\x12\x15\n\rsaved_queries\x18\x11 \x01(\x05:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xf5\x03\n\x08RunModel\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x01\x12\x12\n\nrun_status\x18\x07 \x01(\t\x12\x13\n\x0brun_skipped\x18\x08 \x01(\x08\x12\x1d\n\x15model_materialization\x18\t \x01(\t\x12\"\n\x1amodel_incremental_strategy\x18\n \x01(\t\x12\x10\n\x08model_id\x18\x0b \x01(\t\x12\x17\n\x0fhashed_contents\x18\x0c \x01(\t\x12\x10\n\x08language\x18\r \x01(\t\x12\x11\n\thas_group\x18\x0e \x01(\x08\x12\x19\n\x11\x63ontract_enforced\x18\x0f \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x10 \x01(\t\x12\x11\n\tversioned\x18\x11 \x01(\x08\x12\x1a\n\x12run_skipped_reason\x18\x12 \x01(\t\x12\x14\n\x0crun_model_id\x18\x13 \x01(\t\x12\x15\n\rresource_type\x18\x14 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x96\x02\n\nOnboarding\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x39\n\x06screen\x18\x04 \x01(\x0e\x32).v1.public.events.fusion.OnboardingScreen\x12\x39\n\x06\x61\x63tion\x18\x05 \x01(\x0e\x32).v1.public.events.fusion.OnboardingAction\x12\x0f\n\x07success\x18\x06 \x01(\x08\x12\x0f\n\x07user_id\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01*\xf2\x02\n\x10OnboardingScreen\x12\x16\n\x12SCREEN_UNSPECIFIED\x10\x00\x12\x0b\n\x07WELCOME\x10\x01\x12\x11\n\rPROFILE_CHECK\x10\x02\x12\x11\n\rPROFILE_FOUND\x10\x03\x12\x11\n\rPROFILE_SETUP\x10\x04\x12\x10\n\x0cLINK_ACCOUNT\x10\x05\x12\r\n\tDBT_PARSE\x10\x06\x12\x17\n\x13PARSE_ERROR_AUTOFIX\x10\x07\x12\x13\n\x0f\x44\x42T_PARSE_RETRY\x10\x08\x12\x14\n\x10PARSE_ERROR_FAIL\x10\t\x12\x11\n\rCOMPILE_NO_SA\x10\n\x12\x16\n\x12\x43OMPILE_NO_SA_FAIL\x10\x0b\x12\x0b\n\x07\x43OMPILE\x10\x0c\x12\x10\n\x0c\x43OMPILE_FAIL\x10\r\x12\x0b\n\x07SUCCESS\x10\x0e\x12\x13\n\x0f\x41GENTIC_AUTOFIX\x10\x0f\x12\x17\n\x13TRY_AGENTIC_AUTOFIX\x10\x10\x12\x16\n\x12\x44OWNLOAD_AGENTS_MD\x10\x11*\x93\x01\n\x10OnboardingAction\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\r\n\tINITIATED\x10\x01\x12\x10\n\x0cSCREEN_SHOWN\x10\x02\x12\x0f\n\x0bRUN_STARTED\x10\x03\x12\x10\n\x0cRUN_FINISHED\x10\x04\x12\x12\n\x0eSTEP_COMPLETED\x10\x05\x12\x0f\n\x0bSTEP_FAILED\x10\x06\x42:Z8github.com/dbt-labs/proto-golang/v1/public/events/fusionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dbt-labs/proto-golang/v1/public/events/fusion'
  _globals['_ADAPTERINFO']._loaded_options = None
  _globals['_ADAPTERINFO']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._loaded_options = None
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._serialized_options = b'8\001'
  _globals['_ADAPTERINFOV2']._loaded_options = None
  _globals['_ADAPTERINFOV2']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_INVOCATION']._loaded_options = None
  _globals['_INVOCATION']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_INVOCATIONENV']._loaded_options = None
  _globals['_INVOCATIONENV']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_PACKAGEINSTALL']._loaded_options = None
  _globals['_PACKAGEINSTALL']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_RESOURCECOUNTS']._loaded_options = None
  _globals['_RESOURCECOUNTS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_RUNMODEL']._loaded_options = None
  _globals['_RUNMODEL']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ONBOARDING']._loaded_options = None
  _globals['_ONBOARDING']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ONBOARDINGSCREEN']._serialized_start=2484
  _globals['_ONBOARDINGSCREEN']._serialized_end=2854
  _globals['_ONBOARDINGACTION']._serialized_start=2857
  _globals['_ONBOARDINGACTION']._serialized_end=3004
  _globals['_ADAPTERINFO']._serialized_start=171
  _globals['_ADAPTERINFO']._serialized_end=347
  _globals['_ADAPTERINFOV2']._serialized_start=350
  _globals['_ADAPTERINFOV2']._serialized_end=711
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._serialized_start=643
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._serialized_end=701
  _globals['_INVOCATION']._serialized_start=714
  _globals['_INVOCATION']._serialized_end=974
  _globals['_INVOCATIONENV']._serialized_start=977
  _globals['_INVOCATIONENV']._serialized_end=1127
  _globals['_PACKAGEINSTALL']._serialized_start=1130
  _globals['_PACKAGEINSTALL']._serialized_end=1307
  _globals['_RESOURCECOUNTS']._serialized_start=1310
  _globals['_RESOURCECOUNTS']._serialized_end=1696
  _globals['_RUNMODEL']._serialized_start=1699
  _globals['_RUNMODEL']._serialized_end=2200
  _globals['_ONBOARDING']._serialized_start=2203
  _globals['_ONBOARDING']._serialized_end=2481
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class VortexMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANY_FIELD_NUMBER: builtins.int
    VORTEX_EVENT_CREATED_AT_FIELD_NUMBER: builtins.int
    VORTEX_CLIENT_SENT_AT_FIELD_NUMBER: builtins.int
    VORTEX_BACKEND_RECEIVED_AT_FIELD_NUMBER: builtins.int
    VORTEX_BACKEND_PROCESSED_AT_FIELD_NUMBER: builtins.int
    @property
    def any(self) -> google.protobuf.any_pb2.Any:
        """this can encapsulate any known protobuf message type.

        https://github.com/protocolbuffers/protobuf/blob/main/src/google/protobuf/any.proto
        """

    @property
    def vortex_event_created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time that the event was created by the client. this could
        be different than the time that the event was sent to vortex,
        since the client may buffer events before sending them.
        """

    @property
    def vortex_client_sent_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time that the client sent the message to vortex (recorded
        by the vortex client library automatically).
        """

    @property
    def vortex_backend_received_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time that the vortex api received the message."""

    @property
    def vortex_backend_processed_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the time that the vortex backend fully processed the message."""

    def __init__(
        self,
        *,
        any: google.protobuf.any_pb2.Any | None = ...,
        vortex_event_created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        vortex_client_sent_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        vortex_backend_received_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        vortex_backend_processed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["any", b"any", "vortex_backend_processed_at", b"vortex_backend_processed_at", "vortex_backend_received_at", b"vortex_backend_received_at", "vortex_client_sent_at", b"vortex_client_sent_at", "vortex_event_created_at", b"vortex_event_created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["any", b"any", "vortex_backend_processed_at", b"vortex_backend_processed_at", "vortex_backend_received_at", b"vortex_backend_received_at", "vortex_client_sent_at", b"vortex_client_sent_at", "vortex_event_created_at", b"vortex_event_created_at"]) -> None: ...

Global___VortexMessage: typing_extensions.TypeAlias = VortexMessage

@typing.final
class VortexMessageBatch(google.protobuf.message.Message):
    """internal canonical message for vortex events. this is what
    you receive when you integrate a streaming consumer with vortex.
    it is also what vortex uses internally on its queue.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """a UUID which is a unique identifier for the event, it can be
    provided by the client or autogenerated by the vortex  client
    library.
    """
    @property
    def payload(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___VortexMessage]:
        """the data that was sent to vortex originally. it is retained
        here so that consumers can re-construct the original message
        exactly as they sent it. clients will construct this from
        a valid protobuf message.

        each batch can contain many different message types. this
        will be hidden away from streaming consumers, who will instead
        see the exact protobufs requested come through in their
        subscription.
        """

    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        payload: collections.abc.Iterable[Global___VortexMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["payload", b"payload", "request_id", b"request_id"]) -> None: ...

Global___VortexMessageBatch: typing_extensions.TypeAlias = VortexMessageBatch

@typing.final
class VortexDeadLetterMessage(google.protobuf.message.Message):
    """a message that is sent to the dead letter queue when a message
    is rejected by vortex.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_URL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_BYTES_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    type_url: builtins.str
    """type url of failed message"""
    value: builtins.str
    """a best effort attempt at serializing the rejected message."""
    value_bytes: builtins.bytes
    """original bytes of failed message (for reconstructing or replaying events)."""
    reason: builtins.str
    """the reason that the message was rejected."""
    def __init__(
        self,
        *,
        type_url: builtins.str = ...,
        value: builtins.str = ...,
        value_bytes: builtins.bytes = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reason", b"reason", "type_url", b"type_url", "value", b"value", "value_bytes", b"value_bytes"]) -> None: ...

Global___VortexDeadLetterMessage: typing_extensions.TypeAlias = VortexDeadLetterMessage

@typing.final
class VortexMessageEnrichment(google.protobuf.message.Message):
    """Base enriched event data that all telemetry events inherit from
    Should be explicitly defined as a field "enrichment"
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_IP_FIELD_NUMBER: builtins.int
    CLIENT_PLATFORM_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    @property
    def client_ip(self) -> Global___VortexClientIp:
        """IP address and proxy information of the client"""

    @property
    def client_platform(self) -> Global___VortexClientPlatform:
        """Information about the client platform, including service, client, and library versions"""

    @property
    def user_agent(self) -> Global___VortexUserAgent:
        """User agent information for web-based events"""

    def __init__(
        self,
        *,
        client_ip: Global___VortexClientIp | None = ...,
        client_platform: Global___VortexClientPlatform | None = ...,
        user_agent: Global___VortexUserAgent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_ip", b"client_ip", "client_platform", b"client_platform", "user_agent", b"user_agent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_ip", b"client_ip", "client_platform", b"client_platform", "user_agent", b"user_agent"]) -> None: ...

Global___VortexMessageEnrichment: typing_extensions.TypeAlias = VortexMessageEnrichment

@typing.final
class VortexClientIp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_FIELD_NUMBER: builtins.int
    PROXY_FIELD_NUMBER: builtins.int
    GEO_FIELD_NUMBER: builtins.int
    ip: builtins.str
    """The IP address of the client"""
    proxy: builtins.bool
    """Whether the IP address is from a proxy service"""
    @property
    def geo(self) -> Global___VortexGeolocation:
        """Geographic location information for this IP address"""

    def __init__(
        self,
        *,
        ip: builtins.str = ...,
        proxy: builtins.bool = ...,
        geo: Global___VortexGeolocation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["geo", b"geo"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["geo", b"geo", "ip", b"ip", "proxy", b"proxy"]) -> None: ...

Global___VortexClientIp: typing_extensions.TypeAlias = VortexClientIp

@typing.final
class VortexGeolocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNTRY_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    LATITUDE_FIELD_NUMBER: builtins.int
    LONGITUDE_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    CONTINENT_FIELD_NUMBER: builtins.int
    country: builtins.str
    """Two-letter country code (ISO 3166-1 alpha-2)"""
    city: builtins.str
    """Name of the city"""
    latitude: builtins.float
    """Latitude coordinate"""
    longitude: builtins.float
    """Longitude coordinate"""
    timezone: builtins.str
    """Timezone identifier (e.g., "America/New_York")"""
    continent: builtins.str
    """Name of the continent"""
    def __init__(
        self,
        *,
        country: builtins.str = ...,
        city: builtins.str = ...,
        latitude: builtins.float = ...,
        longitude: builtins.float = ...,
        timezone: builtins.str = ...,
        continent: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["city", b"city", "continent", b"continent", "country", b"country", "latitude", b"latitude", "longitude", b"longitude", "timezone", b"timezone"]) -> None: ...

Global___VortexGeolocation: typing_extensions.TypeAlias = VortexGeolocation

@typing.final
class VortexClientPlatform(google.protobuf.message.Message):
    """Client platform info that every vortex client will set via X-Vortex-Client-Platform
    Expected format is "dbt-core/1.7.0 dbt-vortex-python/1.0.0 dbtlabs-proto/4.25.1"
    See https://github.com/dbt-labs/vortex/pull/101 for more context
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    SERVICE_VERSION_FIELD_NUMBER: builtins.int
    CLIENT_FIELD_NUMBER: builtins.int
    CLIENT_VERSION_FIELD_NUMBER: builtins.int
    DBT_PROTO_LIBRARY_FIELD_NUMBER: builtins.int
    DBT_PROTO_LIBRARY_VERSION_FIELD_NUMBER: builtins.int
    raw: builtins.str
    """Full header value as received"""
    service: builtins.str
    """Source service of the vortex client (i.e. dbt-core)"""
    service_version: builtins.str
    """Version of the source service"""
    client: builtins.str
    """Vortex client used (i.e. vortex-client-rust)"""
    client_version: builtins.str
    """Version of the vortex client"""
    dbt_proto_library: builtins.str
    """Name of the dbt proto library used"""
    dbt_proto_library_version: builtins.str
    """Version of the dbt proto library"""
    def __init__(
        self,
        *,
        raw: builtins.str = ...,
        service: builtins.str = ...,
        service_version: builtins.str = ...,
        client: builtins.str = ...,
        client_version: builtins.str = ...,
        dbt_proto_library: builtins.str = ...,
        dbt_proto_library_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["client", b"client", "client_version", b"client_version", "dbt_proto_library", b"dbt_proto_library", "dbt_proto_library_version", b"dbt_proto_library_version", "raw", b"raw", "service", b"service", "service_version", b"service_version"]) -> None: ...

Global___VortexClientPlatform: typing_extensions.TypeAlias = VortexClientPlatform

@typing.final
class VortexUserAgent(google.protobuf.message.Message):
    """For web based events that send the User-Agent header"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_FIELD_NUMBER: builtins.int
    BROWSER_FIELD_NUMBER: builtins.int
    BROWSER_VERSION_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    OS_VERSION_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    raw: builtins.str
    """Raw User-Agent string as received from the client"""
    browser: builtins.str
    """Name of the browser (e.g., "Chrome", "Firefox")"""
    browser_version: builtins.str
    """Version of the browser"""
    os: builtins.str
    """Operating system name (e.g., "Windows", "macOS")"""
    os_version: builtins.str
    """Operating system version"""
    device: builtins.str
    """Device model or identifier"""
    device_type: builtins.str
    """Type of device (e.g., "mobile", "desktop", "tablet")"""
    def __init__(
        self,
        *,
        raw: builtins.str = ...,
        browser: builtins.str = ...,
        browser_version: builtins.str = ...,
        os: builtins.str = ...,
        os_version: builtins.str = ...,
        device: builtins.str = ...,
        device_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["browser", b"browser", "browser_version", b"browser_version", "device", b"device", "device_type", b"device_type", "os", b"os", "os_version", b"os_version", "raw", b"raw"]) -> None: ...

Global___VortexUserAgent: typing_extensions.TypeAlias = VortexUserAgent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/update/update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9dbtlabs/proto/public/v1/events/fusion/update/update.proto\x12\x1ev1.public.events.fusion.update\"U\n\rPackageUpdate\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0f\n\x07package\x18\x02 \x01(\t\x12\x15\n\x08\x65xe_path\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_exe_pathBAZ?github.com/dbt-labs/proto-golang/v1/public/events/fusion/updateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.update.update_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/dbt-labs/proto-golang/v1/public/events/fusion/update'
  _globals['_PACKAGEUPDATE']._serialized_start=93
  _globals['_PACKAGEUPDATE']._serialized_end=178
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/show_data.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9dbtlabs/proto/public/v1/events/fusion/log/show_data.proto\x12\x1bv1.public.events.fusion.log\"\xe5\x01\n\x0eShowDataOutput\x12H\n\routput_format\x18\x01 \x01(\x0e\x32\x31.v1.public.events.fusion.log.ShowDataOutputFormat\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12\x11\n\tis_inline\x18\x04 \x01(\x08\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07\x63olumns\x18\x06 \x03(\t\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x07 \x01(\tB\x0c\n\n_unique_id*\x8a\x02\n\x14ShowDataOutputFormat\x12\'\n#SHOW_DATA_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12 \n\x1cSHOW_DATA_OUTPUT_FORMAT_TEXT\x10\x01\x12\x1f\n\x1bSHOW_DATA_OUTPUT_FORMAT_CSV\x10\x02\x12\x1f\n\x1bSHOW_DATA_OUTPUT_FORMAT_TSV\x10\x03\x12 \n\x1cSHOW_DATA_OUTPUT_FORMAT_JSON\x10\x04\x12\"\n\x1eSHOW_DATA_OUTPUT_FORMAT_NDJSON\x10\x05\x12\x1f\n\x1bSHOW_DATA_OUTPUT_FORMAT_YML\x10\x06\x42>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.show_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_SHOWDATAOUTPUTFORMAT']._serialized_start=323
  _globals['_SHOWDATAOUTPUTFORMAT']._serialized_end=589
  _globals['_SHOWDATAOUTPUT']._serialized_start=91
  _globals['_SHOWDATAOUTPUT']._serialized_end=320
# @@protoc_insertion_point(module_scope)
